@@ -9,11 +9,11 @@
 
 #include "wimlib/types.h"
 
-extern void
-make_canonical_huffman_code(unsigned num_syms,
-			    unsigned max_codeword_len,
-			    const u32 freq_tab[restrict],
-			    u8 lens[restrict],
-			    u32 codewords[restrict]);
+#define MAX_NUM_SYMS		799	/* LZMS_MAX_NUM_SYMS */
+#define MAX_CODEWORD_LEN	16
+
+void
+make_canonical_huffman_code(unsigned num_syms, unsigned max_codeword_len,
+			    const u32 freqs[], u8 lens[], u32 codewords[]);
 
 #endif /* _WIMLIB_COMPRESS_COMMON_H */
