@@ -8,13 +8,13 @@
 
 struct blob_descriptor;
 
-extern int
+int
 wimboot_alloc_data_source_id(const wchar_t *wim_path,
 			     const u8 guid[GUID_SIZE], int image,
 			     const wchar_t *target, u64 *data_source_id_ret,
 			     bool *wof_running_ret);
 
-extern bool
+bool
 wimboot_set_pointer(HANDLE h,
 		    const struct blob_descriptor *blob,
 		    u64 data_source_id,
