@@ -18,7 +18,7 @@
  * details.
  *
  * You should have received a copy of the GNU Lesser General Public License
- * along with this file; if not, see http://www.gnu.org/licenses/.
+ * along with this file; if not, see https://www.gnu.org/licenses/.
  */
 
 #ifdef HAVE_CONFIG_H
@@ -206,7 +206,7 @@ sort_blob_list_for_solid_compression(struct list_head *blob_list)
 							 blob_table.capacity]);
 			break;
 		case BLOB_IN_FILE_ON_DISK:
-	#ifdef __WIN32__
+	#ifdef _WIN32
 		case BLOB_IN_WINDOWS_FILE:
 	#endif
 			blob_set_solid_sort_name_from_inode(blob, blob->file_inode);
